# Graph Conversion functions

The conversion functions are a collection of different handy helper 
functions for converting your input graphs between different toolboxes.

Popular supported formats are:

* numpy arrays
* networkx graphs
* dgl graphs
* scipy sparse matrices

PHOTONAI Graph will handle necessary conversions in your pipeline automatically.

## Graph Conversion Functions

::: photonai_graph.GraphConversions
